<!DOCTYPE html>
<html>
	<head>
		<title> Film-obsession.com </title>
	</head>

	<style TYPE="text/css">
		#ajax_msg{
			width: 100%;
			text-align: center;
			margin-top: 150px;
		}
	</style>

	<body>
		<div id='ajax_msg'>
			<h1>Loading...</h1>
			<img src="http://img.cdn.tl/loading51.gif" />
		</div>
		<script src="//ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>
		<script>
			window.jQuery || document.write('<script src="{{ STATIC_URL }}js/vendor/jquery-1.9.1.min.js"><\/script>')
		</script>
		<script type="text/javascript">
		
		$(document).ready(function() {
			$.ajax({
				type : "POST",
				url : window.location,
				data: {
					'signed_request':'{{post_info}}',
					'after_splash_screen':true
				},
				dataType : 'html',
				success : function(result){
				  	window.location.href=window.location;
				},
				error : function(request, status, error) {
					//ajax_label.html(request.responseText);
					//alert(request.responseText);
					//alert(status);
					//alert(error);
					$('#ajax_msg').html('Ups! Hemos tenido un problema');
					//window.location.href='{{facebook_main_url}}';
				}
			});
		});
		</script>
	</body>
</html>